@@ -13,7 +13,7 @@ from phiterm.utils.log import set_log_level_to_debug
 
 cli_app = typer.Typer(
     help="""\b
-phi is a tool for building data products.
+Phidata is a toolkit for building data products as code.
 \b
 Get started:
 1. Run `phi init` to init phidata on this machine
@@ -26,7 +26,7 @@ Get started:
     add_completion=False,
     invoke_without_command=True,
     options_metavar="\b",
-    subcommand_metavar="<command>",
+    subcommand_metavar="[command]",
     # https://typer.tiangolo.com/tutorial/exceptions/#disable-local-variables-for-security
     pretty_exceptions_show_locals=False,
 )
@@ -47,6 +47,9 @@ def init(
         "--debug",
         help="Print debug logs.",
     ),
+    login: bool = typer.Option(
+        False, "--login", "-l", help="Login using phidata.com", show_default=True
+    ),
 ):
     """
     \b
@@ -62,10 +65,10 @@ def init(
     if print_debug_log:
         set_log_level_to_debug()
 
-    init_success: bool = initialize_phidata(reset)
+    init_success: bool = initialize_phidata(reset=reset, login=login)
 
 
-@cli_app.command(short_help="Authenticate with phidata.com", hidden=True)
+@cli_app.command(short_help="Authenticate with phidata.com")
 def auth(
     print_debug_log: bool = typer.Option(
         False,
@@ -77,17 +80,13 @@ def auth(
     """
     \b
     Authenticate your account with phidata.
-
-    \b
-    Examples:
-    * `phi auth`
     """
-    from phiterm.cli.cli_operator import authenticate_phidata
+    from phiterm.cli.cli_operator import authenticate_user
 
     if print_debug_log:
         set_log_level_to_debug()
 
-    auth_success: bool = authenticate_phidata()
+    auth_success: bool = authenticate_user()
 
 
 @cli_app.command(short_help="Set current directory as active workspace")
@@ -121,8 +120,8 @@ def set(
     operation_success: bool = set_workspace_as_active(ws_name)
 
 
-@cli_app.command(short_help="Authenticate from the cli", hidden=True)
-def cliauth(
+@cli_app.command(short_help="Log in from the cli")
+def login(
     print_debug_log: bool = typer.Option(
         False,
         "-d",
@@ -132,11 +131,11 @@ def cliauth(
 ):
     """
     \b
-    Authenticate from cli
+    Log in from the cli
 
     \b
     Examples:
-    * `phi cliauth`
+    * `phi login`
     """
     from phiterm.cli.cli_operator import sign_in_using_cli
 
@@ -178,18 +177,23 @@ def ping(
     ),
 ):
     """Ping the phidata servers and check if you are authenticated"""
-    from phiterm.backend_api.auth_api import auth_ping
+    from phiterm.api.user import user_ping, is_user_authenticated
     from phiterm.utils.cli_console import print_info
 
     if print_debug_log:
         set_log_level_to_debug()
 
-    ping_success = auth_ping()
+    ping_success = user_ping()
     if ping_success:
         print_info("Ping successful")
     else:
         print_info("Could not reach phidata servers")
 
+    if is_user_authenticated():
+        print_info("User is authenticated")
+    else:
+        print_info("User is not authenticated, run `phi auth` to log in")
+
 
 @cli_app.command(short_help="Print phidata config", hidden=True)
 def config(
