@@ -71,7 +71,7 @@ def save(
 
     from phiterm.conf.phi_conf import PhiConf, PhiWsData
     from phiterm.k8s.k8s_operator import save_k8s_resources
-    from phiterm.utils.dotenv import load_dotenv
+    from phiterm.utils.load_env import load_env
 
     if print_debug_log:
         set_log_level_to_debug()
@@ -90,7 +90,7 @@ def save(
         return
 
     # Load environment from .env
-    load_dotenv(workspace_root=active_ws_data.ws_root_path)
+    load_env(dotenv_dir=active_ws_data.ws_root_path)
 
     target_name: Optional[str] = None
     target_type: Optional[str] = None
