@@ -3,32 +3,24 @@ from pathlib import Path
 from typing import Dict, List, Optional, Set, Tuple
 
 from phiterm.conf.constants import PHI_CONF_PATH
-from phiterm.schemas.user_schemas import UserSchema
-from phiterm.utils.cli_console import (
-    print_available_workspaces,
-    print_info,
-    print_error,
-    print_heading,
-    print_horizontal_line,
-    print_info,
-    print_subheading,
-)
+from phiterm.schemas.user import UserSchema
+from phiterm.schemas.workspace import WorkspaceSchema
+from phiterm.utils.cli_console import print_heading, print_info
 from phiterm.utils.common import pickle_object_to_file, unpickle_object_from_file
 from phiterm.utils.dttm import current_datetime_utc
 from phiterm.utils.filesystem import delete_from_fs
 from phiterm.utils.log import logger
 from phiterm.workspace.phi_ws_data import PhiWsData
 from phiterm.workspace.ws_enums import WorkspaceSetupActions
-from phiterm.workspace.ws_schemas import WorkspaceSchema
 
 
 class PhiConf:
     """The PhiConf class manages user data for the phi cli"""
 
-    def __init__(self):
+    def __init__(self, user_schema: Optional[UserSchema] = None) -> None:
         # Current user, populated after authenticating with the backend
         # To add a user, use the user setter
-        self._user: Optional[UserSchema] = None
+        self._user: Optional[UserSchema] = user_schema
 
         # Active ws - used as the default for all phi commands
         # To add an active workspace, use the active_ws_name setter
@@ -39,7 +31,8 @@ class PhiConf:
         # When phi is initialized using `phi init`, this is an empty dict
         # When the user is authenticated, we get a list of all the workspaces this user has access to.
         # These workspaces are then added to PhiConf using the `active_ws_name` and `available_ws` setters.
-        # Note: These workspaces arent yet cloned on the users machines and only a record of their availability is kept.
+        # Note: These workspaces are not yet cloned on the users machines and
+        # only a record of their availability is kept.
         # When the workspace is setup on the users machine, we update the remaining workspace data.
 
         # Quick access from ws_path -> ws data.
@@ -88,12 +81,14 @@ class PhiConf:
     def available_ws(self, avl_ws: Optional[List[WorkspaceSchema]]) -> None:
         if avl_ws:
             for ws_schema in avl_ws:
-                self._add_or_update_ws_data(ws_name=ws_schema.name, ws_schema=ws_schema)
+                self._add_or_update_ws_data(
+                    ws_name=ws_schema.ws_name, ws_schema=ws_schema
+                )
             self.save_config()
 
     def _add_or_update_ws_data(
         self,
-        ws_name: str,
+        ws_name: Optional[str] = None,
         ws_schema: Optional[WorkspaceSchema] = None,
         ws_root_path: Optional[Path] = None,
         ws_config_file_path: Optional[Path] = None,
@@ -105,10 +100,10 @@ class PhiConf:
         * This function does not call self.save_config(). call it from the parent.
 
         This function is called from 5 places:
-        1. During `phi auth` when active/available workspaces are requested from the backend.
+        1. During `phi login` when active/available workspaces are requested from the api.
         2. During `phi ws init` when a new workspace is created on the users machine.
-        3. When the user already has a local workspace dir on their machine
-            and need to manually add the ws to the PhiConf
+        3. When the user already has a local workspace on their machine
+            and adds the ws manually using `phi ws setup`
             (possible after running `phi init -r` which deletes the config)
         4. Whenever ws config, creds or data needs to be refreshed. This function is called with just the `ws_name` arg
         5. When active or available workspaces are updated, this function is called from the
@@ -138,12 +133,14 @@ class PhiConf:
             if ws_root_path is not None:
                 self._path_to_ws_data_map[ws_root_path] = self._ws_data_map[ws_name]
                 logger.debug(f"Workspace dir: {ws_root_path}")
-            logger.debug(f"Workspace created: `{ws_name}`")
+            logger.debug(f"Workspace created: {ws_name}")
+            return
 
         ######################################################
         # Update ws_data
         ######################################################
 
+        logger.debug(f"Updating workspace: {ws_name}")
         # By this point there should be a PhiWsData object for this ws_name
         existing_ws_data: PhiWsData = self._ws_data_map.get(
             ws_name, PhiWsData(ws_name=ws_name)
@@ -165,14 +162,9 @@ class PhiConf:
         ):
             logger.debug("Updating ws_config_file_path")
             _ws_data.ws_config_file_path = ws_config_file_path
-
-        # Load the WorkspaceConfig
         _ws_data.last_update_ts = current_datetime_utc()
 
-        # Point the ws_data in _ws_data_map and _path_to_ws_data_map
-        # to new _ws_data
-        logger.debug(f"Updating mapping for: {ws_name}")
-
+        # Point the ws_data in _ws_data_map and _path_to_ws_data_map to new _ws_data
         # 1. Pop the existing object from the self._ws_data_map
         if ws_name in self._ws_data_map:
             popped_ws_data_from_map: Optional[PhiWsData] = self._ws_data_map.pop(
@@ -196,12 +188,13 @@ class PhiConf:
             self._path_to_ws_data_map[_ws_data.ws_root_path] = self._ws_data_map[
                 ws_name
             ]
+        logger.debug(f"Mapping updated for: {ws_name}")
 
-        ######################################################
-        # END
-        ######################################################
+    ######################################################
+    # END
+    ######################################################
 
-    def add_new_created_ws_to_config(
+    def add_new_ws_to_config(
         self,
         ws_name: str,
         ws_root_path: Path,
@@ -215,104 +208,26 @@ class PhiConf:
         )
         self.save_config()
 
-    def update_ws_schema_for_workspace(
-        self,
-        ws_schema: WorkspaceSchema,
-        set_as_active: bool = False,
-    ) -> None:
-        """Updates the schema for a workspace and sets as active if needed"""
-        self._add_or_update_ws_data(
-            ws_name=ws_schema.name,
-            ws_schema=ws_schema,
-        )
-        if set_as_active:
-            self.active_ws_name = ws_schema.name
-        self.save_config()
-
     def update_ws_data(
         self,
         ws_name: str,
         ws_schema: Optional[WorkspaceSchema] = None,
         ws_root_path: Optional[Path] = None,
         ws_config_file_path: Optional[Path] = None,
+        set_as_active: bool = False,
     ) -> None:
         """Update workspace data and return True if successful"""
 
-        logger.debug(f"Updating ws_data for {ws_name}")
         self._add_or_update_ws_data(
             ws_name=ws_name,
             ws_schema=ws_schema,
             ws_root_path=ws_root_path,
             ws_config_file_path=ws_config_file_path,
         )
+        if set_as_active:
+            self.active_ws_name = ws_name
         self.save_config()
 
-    def update_ws_data_for_cloned_ws(
-        self,
-        ws_name: str,
-        ws_root_path: Path,
-        ws_config_file_path: Path,
-    ) -> bool:
-        """For a workspace to be cloned, it would already have ws_data and ws_schema available.
-        After the directory from the git_url is cloned, we can fill in the gaps to update
-        the ws_data for the workspace. Call this function through ws_operator.clone_workspace()
-        """
-        ws_data: Optional[PhiWsData] = self._ws_data_map.get(ws_name, None)
-        if ws_data is None:
-            return False
-
-        self._add_or_update_ws_data(
-            ws_name=ws_name,
-            ws_root_path=ws_root_path,
-            ws_config_file_path=ws_config_file_path,
-        )
-        self.save_config()
-        return True
-
-    def add_ws_data_using_config_file(
-        self, ws_root_path: Path, ws_config_file_path: Optional[Path]
-    ) -> Optional[PhiWsData]:
-        """Maps a ws at `ws_root_path` to an available workspace. using the config file at `ws_config_file_path`.
-        Also updates the ws_config_file_path in the ws_data if provided.
-
-        This is used in 2 cases:
-        1. If the user ran `phi init -r`, the PhiConf gets erased and so does self._path_to_ws_data_map
-            So there is no link from the ws_root_path to the workspace.
-        2. The user manually cloned the workspace directory. In that case we don't have a record of this
-            ws_root_path matching any available workspace.
-
-        This function basically reads the workspace config and tries to map it to an available workspace.
-        Returns the PhiWsData if successful
-        """
-
-        logger.debug(f"Looking for the workspace at {ws_root_path}")
-        _best_guess_ws_name = ws_root_path.stem
-        logger.debug(f"_best_guess_ws_name: {_best_guess_ws_name}")
-        _ws_schema: Optional[WorkspaceSchema] = None
-        for avl_ws in self.available_ws:
-            if avl_ws.name == _best_guess_ws_name:
-                _ws_schema = avl_ws
-            break
-        if _ws_schema is None:
-            print_error(
-                f"Workspace name: {_best_guess_ws_name} does not match any available workspaces"
-            )
-            print_available_workspaces(self.available_ws)
-            return None
-
-        logger.debug(f"Found matching workspace {_ws_schema.name}")
-        logger.debug(
-            f"Mapping {_ws_schema.name} to dir: {ws_root_path} and config: {ws_config_file_path}"
-        )
-        self._add_or_update_ws_data(
-            ws_name=_ws_schema.name,
-            ws_schema=_ws_schema,
-            ws_root_path=ws_root_path,
-            ws_config_file_path=ws_config_file_path,
-        )
-        self.save_config()
-        return self._ws_data_map.get(_ws_schema.name, None)
-
     def validate_workspace(
         self, ws_name: str
     ) -> Tuple[bool, Optional[Set[WorkspaceSetupActions]]]:
@@ -352,12 +267,12 @@ class PhiConf:
                 ws_data.pending_actions.add(
                     WorkspaceSetupActions.GIT_REMOTE_ORIGIN_IS_AVL
                 )
-        elif ws_data.ws_schema.git_url is None:
-            ws_data.pending_actions.add(WorkspaceSetupActions.GIT_REMOTE_ORIGIN_IS_AVL)
-        else:
-            ws_data.pending_actions.discard(
-                WorkspaceSetupActions.GIT_REMOTE_ORIGIN_IS_AVL
-            )
+        # elif ws_data.ws_schema.git_url is None:
+        #     ws_data.pending_actions.add(WorkspaceSetupActions.GIT_REMOTE_ORIGIN_IS_AVL)
+        # else:
+        #     ws_data.pending_actions.discard(
+        #         WorkspaceSetupActions.GIT_REMOTE_ORIGIN_IS_AVL
+        #     )
 
         # logger.debug(f"Required Actions for this workspace: {ws_data.required_actions}")
         # logger.debug(f"Pending Actions for this workspace: {ws_data.pending_actions}")
@@ -378,7 +293,7 @@ class PhiConf:
 
         ws_data: Optional[PhiWsData] = self._ws_data_map.pop(ws_name, None)
         if ws_data is None:
-            print_error(f"No record of workspace {ws_name}")
+            logger.error(f"No record of workspace {ws_name}")
             return False
 
         ws_data_from_path: Optional[PhiWsData]
@@ -471,6 +386,42 @@ class PhiConf:
         logger.debug(f"++**++ Config refreshed: {ws_name}")
         self.save_config()
 
+    ######################################################
+    ## Sync Workspace Data from api
+    ######################################################
+
+    def sync_workspaces_from_api(self) -> bool:
+        from phiterm.api.workspace import (
+            get_primary_workspace,
+            get_available_workspaces,
+        )
+
+        if self.user is None:
+            logger.error("User not available for workspace sync")
+            return False
+
+        # If the active_ws_name is None, call backend to get the primary_ws
+        primary_ws: Optional[WorkspaceSchema] = None
+        if self.active_ws_name is None:
+            primary_ws = get_primary_workspace(self.user)
+            if primary_ws is None:
+                logger.debug("No primary workspace available")
+            else:
+                logger.debug(f"Received primary ws: {primary_ws.json(indent=2)}")
+                self.active_ws_name = primary_ws.ws_name
+
+        # If available_workspaces is empty and a primary_ws is available
+        # call backend to get the available workspaces
+        available_workspaces: Optional[List[WorkspaceSchema]] = None
+        if len(self.available_ws) == 0:
+            available_workspaces = get_available_workspaces(self.user)
+            if available_workspaces is not None:
+                logger.debug(
+                    f"Received {len(available_workspaces)} available workspaces"
+                )
+                self.available_ws = available_workspaces
+        return True
+
     ######################################################
     ## PhiConf functions
     ######################################################
@@ -495,7 +446,7 @@ class PhiConf:
 
     def print_to_cli(self):
         if self.user:
-            print_info(f"* User: {self.user.email}")
+            print_heading(f"User: {self.user.email}")
         if self.active_ws_name:
             print_heading(f"\nActive workspace: {self.active_ws_name}\n")
         else:
@@ -506,5 +457,58 @@ class PhiConf:
             for k, v in self._ws_data_map.items():
                 print_info(f"  {c}. Name: {v.ws_name}")
                 print_info(f"     Dir: {v.ws_root_path}")
+                if v.ws_schema:
+                    logger.debug(
+                        f"     Schema: {v.ws_schema.json(exclude_none=True, indent=2)}"
+                    )
                 print_info(f"  -*-\n")
                 c += 1
+
+    ######################################################
+    ## Deprecated functions
+    ######################################################
+    #
+    # def add_ws_data_using_config_file(
+    #     self, ws_root_path: Path, ws_config_file_path: Optional[Path]
+    # ) -> Optional[PhiWsData]:
+    #     """Maps the workspace at `ws_root_path` to an
+    #     available workspace using the `ws_config_file_path`.
+    #     Also updates the ws_config_file_path in the ws_data if provided.
+    #
+    #     This is used in 2 cases:
+    #     1. If the user ran `phi init -r`, the PhiConf gets erased and so does self._path_to_ws_data_map
+    #         So there is no link from the ws_root_path to the workspace.
+    #     2. The user manually cloned the workspace directory. In that case we don't have a record of this
+    #         ws_root_path matching any available workspace.
+    #
+    #     This function basically reads the workspace config and tries to map it to an available workspace.
+    #     Returns the PhiWsData if successful
+    #     """
+    #
+    #     logger.debug(f"Looking for the workspace at {ws_root_path}")
+    #     _best_guess_ws_name = ws_root_path.stem
+    #     logger.debug(f"_best_guess_ws_name: {_best_guess_ws_name}")
+    #     _ws_schema: Optional[WorkspaceSchema] = None
+    #     for avl_ws in self.available_ws:
+    #         if avl_ws.ws_name == _best_guess_ws_name:
+    #             _ws_schema = avl_ws
+    #         break
+    #     if _ws_schema is None:
+    #         logger.error(
+    #             f"Workspace name: {_best_guess_ws_name} does not match any available workspaces"
+    #         )
+    #         print_available_workspaces(self.available_ws)
+    #         return None
+    #
+    #     logger.debug(f"Found matching workspace {_ws_schema.ws_name}")
+    #     logger.debug(
+    #         f"Mapping {_ws_schema.ws_name} to dir: {ws_root_path} and config: {ws_config_file_path}"
+    #     )
+    #     self._add_or_update_ws_data(
+    #         ws_name=_ws_schema.ws_name,
+    #         ws_schema=_ws_schema,
+    #         ws_root_path=ws_root_path,
+    #         ws_config_file_path=ws_config_file_path,
+    #     )
+    #     self.save_config()
+    #     return self._ws_data_map.get(_ws_schema.ws_name, None)
