@@ -84,10 +84,7 @@ def log_ws_not_available_msg():
 
 
 def log_network_error_msg() -> None:
-    console.print(
-        "NetworkError. Could not reach phidata servers.",
-        style=error_style,
-    )
+    logger.debug("NetworkError. Could not reach phidata servers.")
 
 
 def log_server_error_msg() -> None:
