@@ -4,7 +4,7 @@ from typing import Optional, Dict, List
 
 from phidata.asset import DataAsset
 from phidata.task import Task
-from phidata.dq import DQCheck
+from phidata.check import Check
 from phidata.product import DataProduct
 from phidata.workflow import Workflow
 from phidata.workspace import WorkspaceConfig
@@ -99,7 +99,7 @@ def run_workflow(
     wf_dict: Dict[str, Workflow]
     task_dict: Dict[str, Task]
     da_dict: Dict[str, DataAsset]
-    dq_dict: Dict[str, DQCheck]
+    dq_dict: Dict[str, Check]
     try:
         dp_dict, wf_dict, task_dict, da_dict, dq_dict = parse_workflow_file(
             workflow_file_path
@@ -169,6 +169,19 @@ def run_workflow(
                 ws_data=ws_data,
                 workflows=wf_dict,
             )
+        # ** CASE 4: If a workflow_name is not provided
+        #   and workflow_file does NOT contain DataProducts
+        #   and workflow_file does NOT contain Workflows
+        #   but workflow_file contains Tasks
+        #   Run all Tasks
+        elif task_dict is not None and len(task_dict) > 0:
+            run_status = run_workflows_local(
+                workflow_file=workflow_file,
+                run_context=run_context,
+                ws_data=ws_data,
+                workflows=wf_dict,
+                tasks=task_dict,
+            )
 
     # Run Workflow in docker
     elif target_env == WorkflowEnv.dev:
@@ -521,7 +534,7 @@ def list_workflows(
     wf_dict: Dict[str, Workflow]
     task_dict: Dict[str, Task]
     da_dict: Dict[str, DataAsset]
-    dq_dict: Dict[str, DQCheck]
+    dq_dict: Dict[str, Check]
     try:
         dp_dict, wf_dict, task_dict, da_dict, dq_dict = parse_workflow_file(
             workflow_file_path
