@@ -5,12 +5,12 @@ from typing import List, Optional, Set
 from pydantic import BaseModel
 from phidata.workspace import WorkspaceConfig
 
+from phiterm.schemas.workspace import WorkspaceSchema
 from phiterm.utils.common import is_empty
 from phiterm.utils.dttm import current_datetime_utc
 from phiterm.utils.log import logger
 from phiterm.workspace.ws_enums import WorkspaceSetupActions
 from phiterm.workspace.exceptions import WorkspaceConfigException
-from phiterm.workspace.ws_schemas import WorkspaceSchema
 
 
 class PhiWsData(BaseModel):
