@@ -10,7 +10,7 @@ from phidata.workspace import WorkspaceConfig
 
 from phiterm.conf.constants import DEFAULT_WS_NAME
 from phiterm.conf.phi_conf import PhiConf, PhiWsData
-from phiterm.enums.user_enums import VersionControlProviderEnum
+from phiterm.schemas.workspace import WorkspaceSchema
 from phiterm.utils.cli_console import (
     print_conf_not_available_msg,
     print_heading,
@@ -23,7 +23,6 @@ from phiterm.workspace.ws_enums import (
     WorkspaceStarterTemplate,
 )
 from phiterm.workspace.exceptions import WorkspaceConfigException
-from phiterm.workspace.ws_schemas import WorkspaceSchema
 
 # List of reserved workspace names
 RESERVED_WS_NAMES = ["root", "bedi", "ashpreet", "ashpreetbedi"]
@@ -33,7 +32,7 @@ def create_new_workspace(ws_name: str, template: WorkspaceStarterTemplate) -> bo
     """Creates a new workspace for the user.
     This function clones a phidata template on the users machine at the path:
         cwd/ws_name
-    cwd: current working dir - where the command was ran from.
+    cwd: current working dir - where the command was run from.
 
     Steps:
     1. Validate ws_name and if we can create a folder with that name
@@ -70,11 +69,8 @@ def create_new_workspace(ws_name: str, template: WorkspaceStarterTemplate) -> bo
     _existing_ws_data: Optional[PhiWsData] = phi_conf.get_ws_data_by_name(ws_name)
     if _existing_ws_data is not None:
         logger.error(f"Found existing record for a workspace: {ws_name}")
-        print_info(
-            f"\nNote: If you would like to setup the workspace instead, run `phi ws setup` from the workspace directory"
-        )
         delete_existing_ws_data = typer.confirm(
-            f"Would you like to delete existing record from phidata and create a new record?",
+            f"Would you like to delete existing record from phidata (does not delete any physical files)?",
             default=True,
         )
         if delete_existing_ws_data:
@@ -120,7 +116,7 @@ def create_new_workspace(ws_name: str, template: WorkspaceStarterTemplate) -> bo
         logger.error(f"Could not find workspace config at: {ws_config_file_path}")
         return False
 
-    phi_conf.add_new_created_ws_to_config(
+    phi_conf.add_new_ws_to_config(
         ws_name=ws_name,
         ws_root_path=ws_root_path,
         ws_config_file_path=ws_config_file_path,
@@ -146,103 +142,9 @@ def create_new_workspace(ws_name: str, template: WorkspaceStarterTemplate) -> bo
     return setup_workspace(ws_root_path=ws_root_path)
 
 
-def print_git_setup(
-    ws_name: str,
-    ws_root_path: Path,
-    version_control_provider: Optional[
-        VersionControlProviderEnum
-    ] = VersionControlProviderEnum.GITHUB,
-) -> None:
-    """Prints commands to setup a remote git repo for a workspace"""
-    from phiterm.utils.git import get_remote_origin_for_dir
-
-    # Check if a remote origin is available
-    _remote_origin_url: Optional[str] = get_remote_origin_for_dir(ws_root_path)
-    # logger.debug("_remote_origin_url: {}".format(_remote_origin_url))
-    if _remote_origin_url:
-        print_info(f"Remote origin already set: {_remote_origin_url}")
-        return
-
-    create_new_git_repo_url = "https://github.com/new"
-    create_remote_repo_url: str
-    # TODO: Add more repo urls
-    if version_control_provider == VersionControlProviderEnum.GITHUB:
-        create_remote_repo_url = create_new_git_repo_url
-    else:
-        create_remote_repo_url = create_new_git_repo_url
-
-    print_subheading(f"\nSteps to setup a git repo for workspace: {ws_name}")
-    print_info(f"\nCreate a new git repo named {ws_name} at {create_remote_repo_url}")
-    print_info(
-        f"Then follow the following steps to initialize the directory {ws_name} as a git repo and run git push"
-    )
-    print_info(
-        f"NOTE: These steps will be provided by your version control provider (github, gitlab..), but would look something like:"
-    )
-    print_info(f"       git init")
-    print_info(f"       git add .")
-    print_info(f"       git commit -m 'Init Phidata Workspace'")
-    print_info(f"       git branch -M main")
-    print_info(
-        f"       git remote add origin https://github.com/<USERNAME>/{ws_name}.git"
-    )
-    print_info(f"       git push -u origin main")
-    print_info(f"Run `phi ws setup` after running git push to update your workspace\n")
-
-    _open_browser = typer.confirm(
-        f"Would you like to open your browser to visit: {create_remote_repo_url}\n-->"
-    )
-    if _open_browser:
-        typer.launch(create_remote_repo_url)
-
-
-def clone_workspace(ws_to_clone: WorkspaceSchema, phi_conf: PhiConf) -> None:
-    """Clones an available phidata workspace on the users machine. To clone a ws, the PhiConf
-    already has the ws_data and ws_schema available. We then update the
-    ws_root_path and ws_config_file_path in the ws_data. After updating the
-    path, we're call setup_workspace() to go through our usual setup flow
-    """
-    from phiterm.utils.git import GitCloneProgress
-    from phiterm.workspace.ws_utils import get_ws_config_file_path
-
-    # Check if we can create the workspace in the current dir
-    current_dir: Path = Path("../../workspace").resolve()
-    logger.debug(f"current_dir: {current_dir}")
-    ws_root_path: Path = current_dir.joinpath(ws_to_clone.name)
-    if ws_root_path.exists():
-        logger.error(
-            f"{ws_root_path} already exists, please choose another ws to clone or delete the existing dir and run `phi ws init` again"
-        )
-        return
-
-    print_info(f"Creating {str(ws_root_path)}")
-    # Clone the workspace repo in ws_root_path
-    repo_to_clone = ws_to_clone.git_url
-    _cloned_git_repo: git.Repo = git.Repo.clone_from(
-        repo_to_clone, str(ws_root_path), progress=GitCloneProgress()  # type: ignore
-    )
-    # Validate ws_root_path exists and is a directory
-    if not (ws_root_path.exists() and ws_root_path.is_dir()):
-        logger.error(f"Could not clone workspace, please try again")
-        return
-    # Get ws_config_file_path and validate
-    ws_config_file_path: Path = get_ws_config_file_path(ws_root_path)
-    if not (ws_config_file_path.exists() and ws_config_file_path.is_file()):
-        logger.error(f"Could not find workspace config at: {ws_config_file_path}")
-        return
-    # Update the ws_data in PhiConf
-    phi_conf.update_ws_data_for_cloned_ws(
-        ws_name=ws_to_clone.name,
-        ws_root_path=ws_root_path,
-        ws_config_file_path=ws_config_file_path,
-    )
-    setup_workspace(ws_root_path)
-
-
 def create_workspace_using_input():
-    """Takes input from the user and calls create_new_workspace()
-    This function acts as an intermediary between initialize_workspace() and create_new_workspace()
-    """
+    """Takes input from the user and calls create_new_workspace()"""
+
     from phiterm.utils.common import is_empty, str_to_int
 
     # Get workspace name from user
@@ -280,42 +182,20 @@ def create_workspace_using_input():
 
 def initialize_workspace() -> None:
     """Initialize a phidata workspace.
-    This function is called by `phi ws init` to create/clone a new workspace.
+
+    This function is called by `phi ws init` to create a new workspace.
     """
     phi_conf: Optional[PhiConf] = PhiConf.get_saved_conf()
     if not phi_conf:
         print_conf_not_available_msg()
         return
 
-    # TODO: uncomment when backend is live
-    # available_ws = phi_conf.available_ws
-    # if available_ws:
-    #     print_info("Would you like to:")
-    #     print_info("  [1] Create a new workspace")
-    #     print_info("  [2] Clone an existing workspace")
-    #     print_info("  [3] Enter any other key to exit")
-    #     ws_inp_raw = input("--> ")
-    #     ws_inp_int = str_to_int(ws_inp_raw)
-    #     if ws_inp_int == 1:
-    #         create_workspace_using_input()
-    #     elif ws_inp_int == 2:
-    #         print_info("\nSelect workspace to clone:")
-    #         for idx, avl_ws in enumerate(available_ws, start=1):
-    #             print_info("  [{}] {}".format(idx, avl_ws.name))
-    #         clone_ws_inp_raw = input("--> ")
-    #         clone_ws_inp_int = str_to_int(clone_ws_inp_raw)
-    #         if clone_ws_inp_int:
-    #             ws_to_clone = available_ws[clone_ws_inp_int - 1]
-    #             clone_workspace(ws_to_clone, phi_conf)
-    #         return
-    #     return
-    # else:
     print_heading("New phidata workspace")
     create_workspace_using_input()
 
 
 def setup_workspace(ws_root_path: Path) -> bool:
-    """Set-up a phidata workspace at directory: `ws_root_path`.
+    """Setup a phidata workspace at directory: `ws_root_path`.
     This is the catchall function for a workspace. Run it in a directory and it
     should figure everything out.
 
@@ -336,9 +216,9 @@ def setup_workspace(ws_root_path: Path) -> bool:
     2.1 Create WorkspaceSchema for a NEWLY CREATED WORKSPACE
         If ws_schema is None, this is a NEWLY CREATED WORKSPACE.
         i.e. A new workspace was created using create_new_workspace() <- which is called using `phi ws init`.
-        This ws doesnt yet have a ws_schema, make an api call to zeus to create one.
-        If the api call returns None, then we could not create the workspace and we exit
-    2.2 Update WorkspaceSchema if remote origin has been updated
+        This ws does not have a ws_schema, make an api call to create one.
+        If the api call returns None, then we could not create the workspace.
+    2.2 Update WorkspaceSchema if ws_schema exists
     2.3 Set as active if needed
     2.4 Refresh PhiWsData
 
@@ -397,7 +277,7 @@ def setup_workspace(ws_root_path: Path) -> bool:
 
         # In this case, the local workspace directory exists but PhiConf does not have a record
         print_info(f"Adding {ws_root_path} as a workspace")
-        phi_conf.add_new_created_ws_to_config(
+        phi_conf.add_new_ws_to_config(
             ws_name=ws_root_path.stem,
             ws_root_path=ws_root_path,
             ws_config_file_path=__ws_config_file_path,
@@ -417,90 +297,83 @@ def setup_workspace(ws_root_path: Path) -> bool:
     ######################################################
     # 1.4 Set workspace as active if needed
     ######################################################
-    set_as_active_ws = False
+    is_active_ws = False
 
     # If this is the users first workspace i.e. No active_ws is available, then set as active_ws
-    if phi_conf.active_ws_name is None:
-        set_as_active_ws = True
+    # If this is not the users first workspace, then check if this is the active workspace
+    if phi_conf.active_ws_name is None or phi_conf.active_ws_name == ws_data.ws_name:
+        is_active_ws = True
     # otherwise, ask the user if this should be the active ws
-    elif phi_conf.active_ws_name != ws_data.ws_name:
+    else:
         _set_as_active_ws_inp = typer.confirm(
             f"Would you like to set this as your active workspace",
             default=True,
         )
         if _set_as_active_ws_inp:
-            set_as_active_ws = True
+            is_active_ws = True
 
-    if set_as_active_ws:
+    if is_active_ws:
+        # Set this as the active workspace
         phi_conf.active_ws_name = ws_data.ws_name
 
     ######################################################
     # 1.5 Check if remote origin is available
     ######################################################
     _remote_origin_url: Optional[str] = get_remote_origin_for_dir(ws_root_path)
-    logger.debug("Remote_origin_url: {}".format(_remote_origin_url))
+    logger.debug("Git origin: {}".format(_remote_origin_url))
 
-    # TODO: uncomment this block when the backend is up and running
     ######################################################
     ## 2. Create or Update WorkspaceSchema
     ######################################################
-    # If a ws_schema exists for this workspace, this workspace has been setup before
-    # ws_schema: Optional[WorkspaceSchema] = ws_data.ws_schema
+    # If a ws_schema exists for this workspace, this workspace has a record in the backend
+    ws_schema: Optional[WorkspaceSchema] = ws_data.ws_schema
 
     ######################################################
     # 2.1 Create WorkspaceSchema for a NEWLY CREATED WORKSPACE
     ######################################################
-    # if ws_schema is None:
-    #     # If ws_schema is None, this is a NEWLY CREATED WORKSPACE.
-    #     # We make a call to the backend to create a new ws_schema
-    #     logger.debug("ws_schema not found, trying to create one... ")
-    #     logger.debug("ws_name: {}".format(ws_data.ws_name))
-    #     logger.debug("set_as_active_ws: {}".format(_is_active_ws))
-    #
-    #     ws_schema = upsert_workspace(
-    #         UpsertWorkspaceFromCli(
-    #             name=ws_data.ws_name,
-    #             visibility=WorkspaceVisibilityEnum.PRIVATE.value,
-    #             git_url=_remote_origin_url,
-    #             setup_complete=True,
-    #             extra_data={"upserted_at": dttm_to_dttm_str(current_datetime_utc())},
-    #             is_active_ws_for_user=_is_active_ws,
-    #             only_create=True,
-    #         )
-    #     )
-    #     if ws_schema is not None:
-    #         phi_conf.update_ws_schema_for_workspace(
-    #             ws_schema=ws_schema, set_as_active=_is_active_ws
-    #         )
+    if ws_schema is None:
+        from phiterm.api.workspace import create_workspace
 
-    ######################################################
-    # 2.2 Update WorkspaceSchema if available
-    ######################################################
-    # if ws_schema is not None:
-    #     if _remote_origin_url is not None and _remote_origin_url != ws_schema.git_url:
-    #         print_info(f"Updating workspace git origin to: {_remote_origin_url}")
-    #         ws_schema_updated = update_workspace(
-    #             UpdateWorkspace(
-    #                 id_workspace=ws_schema.id_workspace,
-    #                 git_url=_remote_origin_url,
-    #             )
-    #         )
-    #         if ws_schema_updated is not None:
-    #             # Update the ws_schema for this workspace.
-    #             phi_conf.update_ws_data(
-    #                 ws_name=ws_schema.name,
-    #                 ws_schema=ws_schema_updated,
-    #             )
-    #         else:
-    #             logger.error()(
-    #                 "Could not update git origin, please run `phi ws setup` again"
-    #             )
-    #         logger.debug(f"WorkspaceSchema git url updated to: {ws_schema.git_url}")
+        # If ws_schema is None, this is a NEWLY CREATED WORKSPACE.
+        # We make a call to the backend to create a new ws_schema
+        logger.debug("ws_schema not found, trying to create one... ")
+        logger.debug("ws_name: {}".format(ws_data.ws_name))
+        logger.debug("is_active_ws: {}".format(is_active_ws))
+
+        if phi_conf.user is not None:
+            ws_schema = create_workspace(
+                user=phi_conf.user,
+                workspace=WorkspaceSchema(
+                    ws_name=ws_data.ws_name,
+                    is_primary_ws_for_user=is_active_ws,
+                ),
+            )
+        if ws_schema is not None:
+            phi_conf.update_ws_data(ws_name=ws_data.ws_name, ws_schema=ws_schema)
+    else:
+        from phiterm.api.workspace import update_workspace
+
+        # 2.2 Update WorkspaceSchema
+        logger.debug("ws_schema found, updating... ")
+        logger.debug("ws_name: {}".format(ws_data.ws_name))
+        logger.debug("is_active_ws: {}".format(is_active_ws))
+
+        if phi_conf.user is not None:
+            ws_schema.is_primary_ws_for_user = is_active_ws
+            ws_schema_updated = update_workspace(
+                user=phi_conf.user,
+                workspace=ws_schema,
+            )
+            if ws_schema_updated is not None:
+                # Update the ws_schema for this workspace.
+                phi_conf.update_ws_data(
+                    ws_name=ws_data.ws_name, ws_schema=ws_schema_updated
+                )
 
     ######################################################
     # 2.3 Refresh PhiWsData
     ######################################################
-    # Refresh ws_data because phi_conf.update_ws_schema_for_workspace() or phi_conf.update_ws_data()
+    # Refresh ws_data because phi_conf.update_ws_data()
     # will create a new ws_data object in PhiConf
     # Also, cast it to PhiWsData because ws_data is no longer Optional[PhiWsData]
     ws_data = cast(PhiWsData, phi_conf.get_ws_data_by_name(ws_data.ws_name))
@@ -516,6 +389,7 @@ def setup_workspace(ws_root_path: Path) -> bool:
     if not is_valid_ws_config_file_path(_ws_config_file_path):
         logger.error("Could not validate workspace config")
         return False
+    logger.debug("--> Workspace config is valid")
 
     ######################################################
     # 3.2 Validate PhiWsData
@@ -872,15 +746,8 @@ def patch_workspace(
         print_subheading("Workspace patch failed")
 
 
-def init_workspace_data(ws_schema: WorkspaceSchema, phi_conf: PhiConf):
-    """Initializes workspace data like cloud projects"""
-
-    logger.debug("*=* Initializing workspace data for: {}".format(ws_schema.name))
-    logger.debug("TO_BE_IMPLEMENTED")
-    logger.debug("*=* Workspace data init complete: {}".format(ws_schema.name))
-
-
 def set_workspace_as_active(ws_name: Optional[str], refresh: bool = True) -> bool:
+    from phiterm.api.workspace import update_primary_workspace
 
     ######################################################
     ## 1. Validate Pre-requisites
@@ -942,17 +809,22 @@ def set_workspace_as_active(ws_name: Optional[str], refresh: bool = True) -> boo
             return False
 
     ######################################################
-    # 1.4 Check if this is already the active workspace
+    # 1.4 Make api request if updating active workspace
     ######################################################
-    current_active_ws_name = phi_conf.active_ws_name
-    if new_active_ws_name != current_active_ws_name:
-        # If a ws_schema exists for this workspace, this workspace has been authenticated
-        # with the backend. In this case we need to send an API request to update
-        # the active workspace for this user
+    logger.debug("Updating active workspace api")
+
+    if phi_conf.user is not None:
         ws_schema: Optional[WorkspaceSchema] = active_ws_data.ws_schema
-        if ws_schema is not None:
-            print_info("Updating active workspace with the backend")
-            # If ws_schema is None, this is a local workspace
+        if ws_schema is None:
+            logger.warning(f"Please setup {new_active_ws_name} by running `phi ws setup`")
+        else:
+            updated_workspace_schema = update_primary_workspace(
+                user=phi_conf.user,
+                workspace=ws_schema,
+            )
+            if updated_workspace_schema is not None:
+                # Update the ws_schema for this workspace.
+                phi_conf.update_ws_data(ws_name=new_active_ws_name, ws_schema=updated_workspace_schema)
 
     ######################################################
     ## 2. Set workspace as active
@@ -1034,3 +906,134 @@ def print_workspace_status(
             num_configs_patched += 1
         # white space between runs
         print_info("")
+
+
+######################################################
+## Deprecated functions
+######################################################
+#
+# def print_git_setup(
+#     ws_name: str,
+#     ws_root_path: Path,
+#     version_control_provider: Optional[
+#         VersionControlProviderEnum
+#     ] = VersionControlProviderEnum.GITHUB,
+# ) -> None:
+#     """Prints commands to setup a remote git repo for a workspace"""
+#     from phiterm.utils.git import get_remote_origin_for_dir
+#
+#     # Check if a remote origin is available
+#     _remote_origin_url: Optional[str] = get_remote_origin_for_dir(ws_root_path)
+#     # logger.debug("_remote_origin_url: {}".format(_remote_origin_url))
+#     if _remote_origin_url:
+#         print_info(f"Remote origin already set: {_remote_origin_url}")
+#         return
+#
+#     create_new_git_repo_url = "https://github.com/new"
+#     create_remote_repo_url: str
+#     # TODO: Add more repo urls
+#     if version_control_provider == VersionControlProviderEnum.GITHUB:
+#         create_remote_repo_url = create_new_git_repo_url
+#     else:
+#         create_remote_repo_url = create_new_git_repo_url
+#
+#     print_subheading(f"\nSteps to setup a git repo for workspace: {ws_name}")
+#     print_info(f"\nCreate a new git repo named {ws_name} at {create_remote_repo_url}")
+#     print_info(
+#         f"Then follow the following steps to initialize the directory {ws_name} as a git repo and run git push"
+#     )
+#     print_info(
+#         f"NOTE: These steps will be provided by your version control provider (github, gitlab..), but would look something like:"
+#     )
+#     print_info(f"       git init")
+#     print_info(f"       git add .")
+#     print_info(f"       git commit -m 'Init Phidata Workspace'")
+#     print_info(f"       git branch -M main")
+#     print_info(
+#         f"       git remote add origin https://github.com/<USERNAME>/{ws_name}.git"
+#     )
+#     print_info(f"       git push -u origin main")
+#     print_info(f"Run `phi ws setup` after running git push to update your workspace\n")
+#
+#     _open_browser = typer.confirm(
+#         f"Would you like to open your browser to visit: {create_remote_repo_url}\n-->"
+#     )
+#     if _open_browser:
+#         typer.launch(create_remote_repo_url)
+#
+#
+# def clone_workspace(ws_to_clone: WorkspaceSchema, phi_conf: PhiConf) -> None:
+#     """Clones an available phidata workspace on the users machine. To clone a ws, the PhiConf
+#     already has the ws_data and ws_schema available. We then update the
+#     ws_root_path and ws_config_file_path in the ws_data. After updating the
+#     path, we're call setup_workspace() to go through our usual setup flow
+#     """
+#     from phiterm.utils.git import GitCloneProgress
+#     from phiterm.workspace.ws_utils import get_ws_config_file_path
+#
+#     # Check if we can create the workspace in the current dir
+#     current_dir: Path = Path("../../workspace").resolve()
+#     logger.debug(f"current_dir: {current_dir}")
+#     ws_root_path: Path = current_dir.joinpath(ws_to_clone.name)
+#     if ws_root_path.exists():
+#         logger.error(
+#             f"{ws_root_path} already exists, please choose another directory to clone or delete the existing dir and run `phi ws init` again"
+#         )
+#         return
+#
+#     print_info(f"Creating {str(ws_root_path)}")
+#     # Clone the workspace repo in ws_root_path
+#     repo_to_clone = ws_to_clone.git_url
+#     _cloned_git_repo: git.Repo = git.Repo.clone_from(
+#         repo_to_clone, str(ws_root_path), progress=GitCloneProgress()  # type: ignore
+#     )
+#     # Validate ws_root_path exists and is a directory
+#     if not (ws_root_path.exists() and ws_root_path.is_dir()):
+#         logger.error(f"Could not clone workspace, please try again")
+#         return
+#     # Get ws_config_file_path and validate
+#     ws_config_file_path: Path = get_ws_config_file_path(ws_root_path)
+#     if not (ws_config_file_path.exists() and ws_config_file_path.is_file()):
+#         logger.error(f"Could not find workspace config at: {ws_config_file_path}")
+#         return
+#     # Update the ws_data in PhiConf
+#     phi_conf.update_ws_data(
+#         ws_name=ws_to_clone.ws_name,
+#         ws_root_path=ws_root_path,
+#         ws_config_file_path=ws_config_file_path,
+#     )
+#     setup_workspace(ws_root_path)
+#
+#
+# def init_workspace_data(ws_schema: WorkspaceSchema, phi_conf: PhiConf):
+#     """Initializes workspace data like cloud projects"""
+#
+#     logger.debug("*=* Initializing workspace data for: {}".format(ws_schema.name))
+#     logger.debug("TO_BE_IMPLEMENTED")
+#     logger.debug("*=* Workspace data init complete: {}".format(ws_schema.name))
+#
+# def import_workspace():
+#     # TODO: use code to clone/import existing workspace later
+#     available_ws = phi_conf.available_ws
+#     if available_ws:
+#         print_info("Would you like to:")
+#         print_info("  [1] Create a new workspace")
+#         print_info("  [2] Clone an existing workspace")
+#         print_info("  [3] Enter any other key to exit")
+#         ws_inp_raw = input("--> ")
+#         ws_inp_int = str_to_int(ws_inp_raw)
+#         if ws_inp_int == 1:
+#             create_workspace_using_input()
+#         elif ws_inp_int == 2:
+#             print_info("\nSelect workspace to clone:")
+#             for idx, avl_ws in enumerate(available_ws, start=1):
+#                 print_info("  [{}] {}".format(idx, avl_ws.name))
+#             clone_ws_inp_raw = input("--> ")
+#             clone_ws_inp_int = str_to_int(clone_ws_inp_raw)
+#             if clone_ws_inp_int:
+#                 ws_to_clone = available_ws[clone_ws_inp_int - 1]
+#                 clone_workspace(ws_to_clone, phi_conf)
+#             return
+#         return
+#     else:
+#
