@@ -1,14 +1,13 @@
 from pathlib import Path
 from typing import Dict, Optional, Set, Tuple
 
-from phiterm.backend_api.api_exceptions import CliAuthException
-from phiterm.backend_api.auth_api import authenticate_and_get_user_schema
+from phiterm.api.exceptions import CliAuthException
 from phiterm.conf.constants import PHI_SIGNIN_URL_WITHOUT_PARAMS
 from phiterm.conf.phi_conf import PhiWsData
 from phiterm.schemas.user_schemas import UserSchema
 from phiterm.utils.cli_auth_server import (
     get_port_for_auth_server,
-    get_tmp_access_token_from_web_flow,
+    get_auth_token_from_web_flow,
 )
 from phiterm.utils.cli_console import (
     print_info,
@@ -202,31 +201,6 @@ def is_valid_ws_config_file_path(ws_config_file_path: Optional[Path]) -> bool:
     return False
 
 
-def select_version_contol_using_web_flow() -> Optional[UserSchema]:
-    import typer
-
-    port = get_port_for_auth_server()
-    redirect_uri = "http%3A%2F%2Flocalhost%3A{}%2F".format(port)
-    auth_url = "{}?source=cli&action=SELECT_VERSION_CONTROL&redirect_uri={}".format(
-        PHI_SIGNIN_URL_WITHOUT_PARAMS, redirect_uri
-    )
-    print_info("\nYour browser will be opened to visit:\n\n{}\n".format(auth_url))
-    typer.launch(auth_url)
-    print_info("Waiting for a response from browser")
-
-    tmp_access_token = get_tmp_access_token_from_web_flow(port)
-    if tmp_access_token is None:
-        print_error("tmp_access_token")
-        return None
-    try:
-        user: Optional[UserSchema] = authenticate_and_get_user_schema(tmp_access_token)
-    except CliAuthException as e:
-        print_error("CliAuthException")
-        return None
-
-    return user
-
-
 def get_ws_setup_status(ws_data: PhiWsData) -> Tuple[bool, str]:
     """This function validates that a workspace is properly set up and returns an
     error message if ws not setup. The error message is displayed to the user,
@@ -278,7 +252,7 @@ def get_ws_setup_status(ws_data: PhiWsData) -> Tuple[bool, str]:
     if (
         ws_data is not None
         and ws_data.ws_schema is not None
-        and is_empty(ws_data.ws_schema.git_url)
+        # and is_empty(ws_data.ws_schema.git_url)
     ):
         return (
             False,
